@@ -18,5 +18,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+/** \file isprefix.h
+ * String prefix text function. */
+#ifndef ISPREFIX_H
+#  define ISPREFIX_H
+
 /** Return true if TIP is a prefix of ICEBERG. */
 int isprefix(char const *tip, char const *iceberg);
+
+#endif                          /* !ISPREFIX_H */
