@@ -20,14 +20,38 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/** \private Internal state while computing an MD4 hash. */
+/** \file mdfour.h
+ * MD4 message digest algorithm.
+ *
+ * \todo Perhaps use the MD4 routine from OpenSSL if it's installed. It's
+ * probably not worth the trouble.
+ *
+ * This was originally written by Andrew Tridgell for use in Samba. It was then
+ * modified by;
+ *
+ * 2002-06-xx: Robert Weber <robert.weber@Colorado.edu> optimisations and fixed
+ * >512M support.
+ *
+ * 2002-06-27: Donovan Baarda <abo@minkirri.apana.org.au> further optimisations
+ * and cleanups.
+ *
+ * 2004-09-09: Simon Law <sfllaw@debian.org> handle little-endian machines that
+ * can't do unaligned access (e.g. ia64, pa-risc). */
+#ifndef MDFOUR_H
+#  define MDFOUR_H
+
+#  include <stdint.h>
+
+/** The rs_mdfour state type. */
 struct rs_mdfour {
     unsigned int A, B, C, D;
-#ifdef UINT64_MAX
+#  ifdef UINT64_MAX
     uint64_t totalN;
-#else
+#  else
     uint32_t totalN_hi, totalN_lo;
-#endif
+#  endif
     int tail_len;
     unsigned char tail[64];
 };
+
+#endif                          /* !MDFOUR_H */
