@@ -43,11 +43,12 @@
  *
  * \todo Add an option for delta to check whether the files are identical. */
 
-#include "config.h"
+#include "config.h"             /* IWYU pragma: keep */
 #include <stdlib.h>
 #include <stdarg.h>
 #include <string.h>
 #include <popt.h>
+#include <stdio.h>
 #include "librsync.h"
 #include "isprefix.h"
 
