@@ -23,7 +23,7 @@
  * \todo Other things to show in statistics: number of input and output bytes,
  * number of times we blocked waiting for input or output, number of blocks. */
 
-#include "config.h"
+#include "config.h"             /* IWYU pragma: keep */
 #include <stdio.h>
 #include "librsync.h"
 #include "trace.h"
@@ -84,10 +84,8 @@ char *rs_format_stats(rs_stats_t const *stats, char *buf, size_t size)
         sec = 1;                // avoid division by zero
     mb_in = (double)stats->in_bytes / 1e6;
     mb_out = (double)stats->out_bytes / 1e6;
-    len +=
-        snprintf(buf + len, size - (size_t)len,
-                 " speed[%.1f MB (%.1f MB/s) in, %.1f MB (%.1f MB/s) out, %d sec]",
-                 mb_in, mb_in / sec, mb_out, mb_out / sec, sec);
-
+    snprintf(buf + len, size - (size_t)len,
+             " speed[%.1f MB (%.1f MB/s) in, %.1f MB (%.1f MB/s) out, %d sec]",
+             mb_in, mb_in / sec, mb_out, mb_out / sec, sec);
     return buf;
 }
