@@ -20,6 +20,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+/** \file util.h
+ * Misc utility functions used by librsync. */
+#ifndef UTIL_H
+#  define UTIL_H
+
+#  include <stddef.h>
+#  include "librsync.h"
+
 void *rs_alloc(size_t size, char const *name);
 void *rs_realloc(void *ptr, size_t size, char const *name);
 void *rs_alloc_struct0(size_t size, char const *name);
@@ -30,13 +38,15 @@ int rs_long_ln2(rs_long_t v);
 int rs_long_sqrt(rs_long_t v);
 
 /** Allocate and zero-fill an instance of TYPE. */
-#define rs_alloc_struct(type)				\
+#  define rs_alloc_struct(type)				\
         ((type *) rs_alloc_struct0(sizeof(type), #type))
 
-#ifdef __GNUC__
-#  define UNUSED(x) x __attribute__((unused))
-#elif defined(__LCLINT__) || defined(S_SPLINT_S)
-#  define UNUSED(x) /*@unused@*/ x
-#else                           /* !__GNUC__ && !__LCLINT__ */
-#  define UNUSED(x) x
-#endif                          /* !__GNUC__ && !__LCLINT__ */
+#  ifdef __GNUC__
+#    define UNUSED(x) x __attribute__((unused))
+#  elif defined(__LCLINT__) || defined(S_SPLINT_S)
+#    define UNUSED(x) /*@unused@*/ x
+#  else                         /* !__GNUC__ && !__LCLINT__ */
+#    define UNUSED(x) x
+#  endif                        /* !__GNUC__ && !__LCLINT__ */
+
+#endif                          /* !UTIL_H */
