@@ -21,8 +21,6 @@
 
 /* Force DEBUG on so that tests can use assert(). */
 #undef NDEBUG
-#include <stdio.h>
-#include <stdint.h>
 #include <assert.h>
 #include "rabinkarp.h"
 
